@@ -58,7 +58,7 @@ if SESSION_REDIS_URL is None:
     SESSION_REDIS_ENV_URLS = getattr(
         settings,
         'SESSION_REDIS_ENV_URLS', (
-            'REDISCLOUD_URL'
+            'REDISCLOUD_URL',
             'REDISTOGO_URL',
             'OPENREDIS_URL',
             'REDISGREEN_URL',
